#ifdef __unix__
#define SELECT_STOPLIST {\
	if (strcmp (lang, "en") == 0) {\
		stoplist = stoplist_en;\
		stoplist_len = sizeof (stoplist_en);\
	}	else if (strcmp (lang, "de") == 0) {\
		stoplist = stoplist_de;\
		stoplist_len = sizeof (stoplist_de);\
	} else if (strcmp (lang, "fr") == 0) {\
		stoplist = stoplist_fr;\
		stoplist_len = sizeof (stoplist_fr);\
	} else if (strcmp (lang, "hu") == 0) {\
		stoplist = stoplist_hu;\
		stoplist_len = sizeof (stoplist_hu);\
	} else if (strcmp (lang, "ru") == 0) {\
		stoplist = stoplist_ru;\
		stoplist_len = sizeof (stoplist_ru);\
	}	else if (strcmp (lang, "sv") == 0) {\
		stoplist = stoplist_sv;\
		stoplist_len = sizeof (stoplist_sv);\
	}	else if (strcmp (lang, "fi") == 0) {\
		stoplist = stoplist_fi;\
		stoplist_len = sizeof (stoplist_fi);\
	}	else if (strcmp (lang, "pt") == 0) {\
		stoplist = stoplist_pt;\
		stoplist_len = sizeof (stoplist_pt);\
	}	else if (strcmp (lang, "es") == 0) {\
		stoplist = stoplist_es;\
		stoplist_len = sizeof (stoplist_es);\
	} else if (strcmp (lang, "it") == 0) {\
		stoplist = stoplist_it;\
		stoplist_len = sizeof (stoplist_it);\
	} else if (strcmp (lang, "bn") == 0) {\
		stoplist = stoplist_bn;\
		stoplist_len = sizeof (stoplist_bn);\
	}	else if (strcmp (lang, "hi") == 0) {\
		stoplist = stoplist_hi;\
		stoplist_len = sizeof (stoplist_hi);\
	} else if (strcmp (lang, "fa") == 0) {\
		stoplist = stoplist_fa;\
		stoplist_len = sizeof (stoplist_fa);\
	} else if (strcmp (lang, "pl") == 0) {\
		stoplist = stoplist_pl;\
		stoplist_len = sizeof (stoplist_pl);\
	} else if (strcmp (lang, "ar") == 0) {\
		stoplist = stoplist_ar;\
		stoplist_len = sizeof (stoplist_ar);\
	} else if (strcmp (lang, "cs") == 0) {\
		stoplist = stoplist_cs;\
		stoplist_len = sizeof (stoplist_cs);\
	} else if (strcmp (lang, "ro") == 0) {\
		stoplist = stoplist_ro;\
		stoplist_len = sizeof (stoplist_ro);\
	} else if (strcmp (lang, "bg") == 0) {\
		stoplist = stoplist_bg;\
		stoplist_len = sizeof (stoplist_bg);\
	} else {\
		stoplist = stoplist_en;\
		stoplist_len = sizeof (stoplist_en);\
	}\
}
#else

#define SELECT_STOPLIST {\
	stoplist = stoplist_en;\
	stoplist_len = sizeof (stoplist_en);\
};

#endif


char *stoplist_en [] = {
"about",
"according",
"actually",
"adj",
"after",
"afterwards",
"again",
"against",
"all",
"almost",
"alone",
"along",
"already",
"also",
"although",
"always",
"among",
"amongst",
"an",
"and",
"another",
"any",
"anyhow",
"anyone",
"anything",
"are",
"aren't",
"around",
"as",
"at",
"be",
"became",
"because",
"become",
"becomes",
"becoming",
"been",
"before",
"beforehand",
"behind",
"being",
"below",
"beside",
"besides",
"between",
"beyond",
"both",
"but",
"by",
"can't",
"cannot",
"caption",
"could",
"couldn't",
"did",
"didn't",
"do",
"does",
"doesn't",
"don't",
"during",
"eg",
"either",
"else",
"elsewhere",
"enough",
"etc",
"ever",
"everyone",
"everything",
"everywhere",
"except",
"few",
"for",
"formerly",
"from",
"further",
"had",
"has",
"hasn't",
"have",
"haven't",
"he",
"he'd",
"he'll",
"he's",
"hence",
"her",
"here",
"here's",
"hereafter",
"hereby",
"herein",
"hereupon",
"hers",
"herself",
"him",
"himself",
"his",
"how",
"however",
"i'd",
"i'll",
"i'm",
"i've",
"ie",
"if",
"in",
"indeed",
"instead",
"into",
"is",
"isn't",
"it",
"it's",
"its",
"itself",
"later",
"latter",
"latterly",
"least",
"less",
"let",
"let's",
"likely",
"many",
"maybe",
"meantime",
"meanwhile",
"might",
"more",
"moreover",
"mostly",
"much",
"must",
"myself",
"namely",
"neither",
"never",
"nevertheless",
"no",
"nobody",
"none",
"nonetheless",
"noone",
"nor",
"not",
"nothing",
"nowhere",
"of",
"often",
"on",
"once",
"one's",
"only",
"onto",
"or",
"other",
"others",
"otherwise",
"our",
"ours",
"ourselves",
"perhaps",
"rather",
"recently",
"seem",
"seemed",
"seeming",
"seems",
"several",
"shall",
"she",
"she'd",
"she'll",
"she's",
"should",
"shouldn't",
"since",
"so",
"some",
"somehow",
"someone",
"something",
"sometime",
"sometimes",
"somewhere",
"still",
"such",
"than",
"that",
"that'll",
"that's",
"that've",
"the",
"their",
"them",
"themselves",
"then",
"thence",
"there",
"there'd",
"there'll",
"there're",
"there's",
"there've",
"thereafter",
"thereby",
"therefore",
"therein",
"thereupon",
"these",
"they",
"they'd",
"they'll",
"they're",
"they've",
"thirty",
"this",
"those",
"through",
"throughout",
"thus",
"to",
"too",
"toward",
"towards",
"unless",
"unlike",
"unlikely",
"until",
"up",
"upon",
"us",
"very",
"via",
"was",
"wasn't",
"we",
"we'd",
"we'll",
"we're",
"we've",
"well",
"were",
"weren't",
"what",
"what'll",
"what's",
"what've",
"whatever",
"when",
"whence",
"whenever",
"where",
"where's",
"whereafter",
"whereas",
"whereby",
"wherein",
"whereupon",
"wherever",
"whether",
"which",
"while",
"whither",
"who",
"who'd",
"who'll",
"who's",
"whoever",
"whole",
"whom",
"whomever",
"whose",
"why",
"will",
"with",
"within",
"without",
"won't",
"would",
"wouldn't",
"yet",
"you",
"you'd",
"you'll",
"you're",
"you've",
"your",
"yours",
"yourself",
"yourselves"
};


#ifdef __unix__
	
char *stoplist_bn [] = {
"অনেক",
"অন্য",
"অবশ্য",
"আগে",
"আছে",
"আছে",
"আজ",
"আবার",
"আমরা",
"আমাদের",
"আর",
"ই",
"উত্তর",
"উপর",
"উপরে",
"এ",
"এই",
"এক্",
"এখন",
"এত",
"এব",
"এমন",
"এমনি",
"এর",
"এস",
"এসে",
"ও",
"ওই",
"কমনে",
"করা",
"করে",
"করে",
"কাছে",
"কাজ",
"কাজে",
"কারণ",
"কি",
"কিছু",
"কে",
"কেউ",
"কেখা",
"কেন",
"কোটি",
"কোনো",
"কয়েক",
"খুব",
"গিয়ে",
"গেল",
"চার",
"চালু",
"চেষ্টা",
"ছিল",
"ছিল",
"জানা",
"জ্নজন",
"টি",
"তখন",
"তবে",
"তা",
"তাই",
"তো",
"থাকা",
"থেকে",
"দিন",
"দু",
"দুই",
"দেওয়া",
"ধামার",
"নতুন",
"না",
"নাগাদ",
"নিয়ে",
"নেওয়া",
"নয়",
"পর",
"পরে",
"পাচ",
"পি",
"পেয়্র্",
"প্রতি",
"প্রথম",
"প্রযন্ত",
"প্রাথমিক",
"প্রায়",
"বক্তব্য",
"বন",
"বলা",
"বলে",
"বলেন",
"বহু",
"বা",
"বি",
"বিভিন্ন",
"বেশ",
"বেশি",
"মতো",
"মধ্যে",
"মনে",
"যখন",
"যদি",
"যা",
"যাওয়া",
"যে",
"র",
"রকম",
"লক্ষ",
"শুধু",
"শুরু",
"সঙ্গে",
"সব",
"সহ",
"সাধারণ",
"সামনে",
"সি",
"সে",
"সেই",
"হতে",
"হাজার",
"হয়",
};


char *stoplist_hi [] = {
"अंदर",
"अत",
"अपना",
"अपनी",
"अपने",
"अभी",
"आप",
"इत्यादि",
"इन",
"इनका",
"इन्हीं",
"इन्हें",
"इन्हों",
"इस",
"इसका",
"इसकी",
"इसके",
"इसमें",
"इसी",
"इसे",
"उन",
"उनका",
"उनकी",
"उनके",
"उनको",
"उन्हीं",
"उन्हें",
"उन्हों",
"उस",
"उसके",
"उसी",
"उसे",
"एक",
"एवं",
"एस",
"ऐसे",
"और",
"कर",
"करता",
"करते",
"करना",
"करने",
"करें",
"कहते",
"कहा",
"का",
"काफ़ी",
"कि",
"कितना",
"किन्हें",
"किन्हों",
"किया",
"किर",
"किस",
"किसी",
"किसे",
"कुछ",
"कुल",
"को",
"कोई",
"कौन",
"कौनसा",
"गया",
"घर",
"जब",
"जहाँ",
"जा",
"जितना",
"जिन",
"जिन्हें",
"जिन्हों",
"जिस",
"जिसे",
"जीधर",
"जैसा",
"जैसे",
"जो",
"तक",
"तब",
"तरह",
"तिन",
"तिन्हें",
"तिन्हों",
"तिस",
"तिसे",
"तो",
"था",
"थी",
"थे",
"दबारा",
"दिया",
"दुसरा",
"दूसरे",
"दो",
"द्वारा",
"न",
"नहीं",
"ना",
"निहायत",
"नीचे",
"ने",
"पर",
"पहले",
"पूरा",
"पे",
"फिर",
"बनी",
"बही",
"बहुत",
"बाद",
"बाला",
"बिलकुल",
"भी",
"भीतर",
"मगर",
"मानो",
"मे",
"यदि",
"यह",
"यहाँ",
"यही",
"या",
"यिह",
"ये",
"रखें",
"रहा",
"रहे",
"ऱ्वासा",
"लिए",
"लिये",
"लेकिन",
"व",
"वर्ग",
"वह",
"वहाँ",
"वहीं",
"वाले",
"वुह",
"वे",
"वग़ैरह",
"संग",
"सकता",
"सकते",
"सबसे",
"सभी",
"साथ",
"साबुत",
"साभ",
"सारा",
"से",
"सो",
"ही",
"हुआ",
"हुई",
"हुए",
"हैं",
"हो",
"होता",
"होती",
"होते",
"होना",
"होने",
"﻿के",
};



char *stoplist_fa [] = {
"آباد",
"آره",
"آری",
"آمد",
"آمده",
"آن",
"آنان",
"آنجا",
"آنكه",
"آنها",
"آنچه",
"آورد",
"آورده",
"آيد",
"آیا",
"اثرِ",
"از",
"است",
"استفاده",
"اش",
"اكنون",
"البته",
"البتّه",
"ام",
"اما",
"امروز",
"امسال",
"اند",
"انکه",
"او",
"اول",
"اي",
"ايشان",
"ايم",
"اين",
"اينكه",
"اگر",
"با",
"بار",
"بارة",
"باره",
"باشد",
"باشند",
"باشيم",
"بالا",
"بالایِ",
"بايد",
"بدون",
"بر",
"برابرِ",
"براساس",
"براي",
"برایِ",
"برخوردار",
"برخي",
"برداري",
"بروز",
"بسيار",
"بسياري",
"بعد",
"بعری",
"بعضي",
"بلكه",
"بله",
"بلکه",
"بلی",
"بنابراين",
"بندي",
"به",
"بهترين",
"بود",
"بودن",
"بودند",
"بوده",
"بي",
"بيست",
"بيش",
"بيشتر",
"بيشتري",
"بين",
"بی",
"بیرونِ",
"تا",
"تازه",
"تاكنون",
"تان",
"تحت",
"تر",
"ترين",
"تمام",
"تمامي",
"تنها",
"تواند",
"توانند",
"توسط",
"تولِ",
"تویِ",
"جا",
"جاي",
"جايي",
"جدا",
"جديد",
"جريان",
"جز",
"جلوگيري",
"جلویِ",
"حتي",
"حدودِ",
"حق",
"خارجِ",
"خدمات",
"خواست",
"خواهد",
"خواهند",
"خواهيم",
"خود",
"خويش",
"خیاه",
"داد",
"دادن",
"دادند",
"داده",
"دارد",
"دارند",
"داريم",
"داشت",
"داشتن",
"داشتند",
"داشته",
"دانست",
"دانند",
"در",
"درباره",
"دنبالِ",
"ده",
"دهد",
"دهند",
"دو",
"دوم",
"ديده",
"ديروز",
"ديگر",
"ديگران",
"ديگري",
"دیگر",
"را",
"راه",
"رفت",
"رفته",
"روب",
"روزهاي",
"روي",
"رویِ",
"ريزي",
"زياد",
"زير",
"زيرا",
"زیرِ",
"سابق",
"ساخته",
"سازي",
"سراسر",
"سریِ",
"سعي",
"سمتِ",
"سوم",
"سوي",
"سویِ",
"سپس",
"شان",
"شايد",
"شد",
"شدن",
"شدند",
"شده",
"شش",
"شما",
"شناسي",
"شود",
"شوند",
"صورت",
"ضدِّ",
"ضمن",
"طبقِ",
"طريق",
"طور",
"طي",
"عقبِ",
"علّتِ",
"عنوانِ",
"غير",
"فقط",
"فكر",
"فوق",
"قابل",
"قبل",
"قصدِ",
"كرد",
"كردم",
"كردن",
"كردند",
"كرده",
"كسي",
"كل",
"كمتر",
"كند",
"كنم",
"كنند",
"كنيد",
"كنيم",
"كه",
"لطفاً",
"ما",
"مان",
"مانند",
"مانندِ",
"مثل",
"مثلِ",
"مختلف",
"مدّتی",
"مردم",
"مرسی",
"مقابل",
"من",
"مورد",
"مي",
"ميليارد",
"ميليون",
"مگر",
"ناشي",
"نام",
"نبايد",
"نبود",
"نخست",
"نخستين",
"نخواهد",
"ندارد",
"ندارند",
"نداشته",
"نزديك",
"نزدِ",
"نزدیکِ",
"نشان",
"نشده",
"نظير",
"نكرده",
"نمايد",
"نمي",
"نه",
"نوعي",
"نيز",
"نيست",
"ها",
"هاي",
"هايي",
"هر",
"هرگز",
"هزار",
"هست",
"هستند",
"هستيم",
"هفت",
"هم",
"همان",
"همه",
"همواره",
"همين",
"همچنان",
"همچنين",
"همچون",
"همین",
"هنوز",
"هنگام",
"هنگامِ",
"هنگامی",
"هيچ",
"هیچ",
"و",
"وسطِ",
"وقتي",
"وقتیکه",
"ولی",
"وي",
"وگو",
"يا",
"يابد",
"يك",
"يكديگر",
"يكي",
"ّه",
"پاعینِ",
"پس",
"پنج",
"پيش",
"پیش",
"پیشِ",
"چرا",
"چطور",
"چند",
"چندین",
"چنين",
"چه",
"چهار",
"چون",
"چيزي",
"چگونه",
"چیز",
"چیزی",
"چیست",
"کجا",
"کجاست",
"کدام",
"کس",
"کسی",
"کنارِ",
"که",
"کَی",
"کی",
"گذاري",
"گذاشته",
"گردد",
"گرفت",
"گرفته",
"گروهي",
"گفت",
"گفته",
"گويد",
"گويند",
"گيرد",
"گيري",
"یا",
"یک",
};


char *stoplist_pl [] = {
"ach",
"aj",
"albo",
"bardzo",
"bez",
"bo",
"być",
"ci",
"ciebie",
"cię",
"co",
"czy",
"daleko",
"dla",
"dlaczego",
"dlatego",
"do",
"dobrze",
"dokąd",
"dość",
"dużo",
"dwa",
"dwaj",
"dwie",
"dwoje",
"dzisiaj",
"dziś",
"gdyby",
"gdzie",
"go",
"ich",
"ile",
"im",
"inny",
"ja",
"jak",
"jakby",
"jaki",
"je",
"jeden",
"jedna",
"jedno",
"jego",
"jej",
"jemu",
"jest",
"jestem",
"jeśli",
"jeżeli",
"już",
"ją",
"każdy",
"kiedy",
"kierunku",
"kto",
"ku",
"lub",
"ma",
"mają",
"mam",
"mi",
"mnie",
"mną",
"moi",
"moja",
"moje",
"może",
"mu",
"my",
"mój",
"na",
"nam",
"nami",
"nas",
"nasi",
"nasz",
"nasza",
"nasze",
"natychmiast",
"nic",
"nich",
"nie",
"niego",
"niej",
"niemu",
"nigdy",
"nim",
"nimi",
"nią",
"niż",
"obok",
"od",
"około",
"on",
"ona",
"one",
"oni",
"ono",
"owszem",
"po",
"pod",
"ponieważ",
"przed",
"przedtem",
"sam",
"sama",
"się",
"skąd",
"są",
"tak",
"taki",
"tam",
"ten",
"to",
"tobie",
"tobą",
"tu",
"tutaj",
"twoi",
"twoja",
"twoje",
"twój",
"ty",
"wam",
"wami",
"was",
"wasi",
"wasz",
"wasza",
"wasze",
"we",
"więc",
"wszystko",
"wtedy",
"wy",
"zawsze",
"żaden",
"że",
};


char *stoplist_ar [] = {
"،",
"أ",
"ا",
"اثر",
"اجل",
"احد",
"اخرى",
"اذا",
"اربعة",
"اطار",
"اعادة",
"اعلنت",
"اف",
"اكثر",
"اكد",
"الا",
"الاخيرة",
"الان",
"الاول",
"الاولى",
"التى",
"التي",
"الثاني",
"الثانية",
"الذاتي",
"الذى",
"الذي",
"الذين",
"السابق",
"الف",
"الماضي",
"المقبل",
"الوقت",
"الى",
"اليوم",
"اما",
"امام",
"امس",
"ان",
"انه",
"انها",
"او",
"اول",
"اي",
"ايار",
"ايام",
"ايضا",
"ب",
"باسم",
"بان",
"برس",
"بسبب",
"بشكل",
"بعد",
"بعض",
"بن",
"به",
"بها",
"بين",
"تم",
"ثلاثة",
"ثم",
"جميع",
"حاليا",
"حتى",
"حوالى",
"حول",
"حيث",
"حين",
"خلال",
"دون",
"ذلك",
"زيارة",
"سنة",
"سنوات",
"شخصا",
"صباح",
"صفر",
"ضد",
"ضمن",
"عام",
"عاما",
"عدة",
"عدد",
"عدم",
"عشر",
"عشرة",
"على",
"عليه",
"عليها",
"عن",
"عند",
"عندما",
"غدا",
"غير",
"ـ",
"ف",
"فان",
"فى",
"في",
"فيه",
"فيها",
"قال",
"قبل",
"قد",
"قوة",
"كان",
"كانت",
"كل",
"كلم",
"كما",
"لا",
"لدى",
"لقاء",
"لكن",
"للامم",
"لم",
"لن",
"له",
"لها",
"لوكالة",
"ما",
"مايو",
"مساء",
"مع",
"مقابل",
"مليار",
"مليون",
"من",
"منذ",
"منها",
"نحو",
"نفسه",
"نهاية",
"هذا",
"هذه",
"هناك",
"هو",
"هي",
"و",
"و6",
"واحد",
"واضاف",
"واضافت",
"واكد",
"وان",
"واوضح",
"وفي",
"وقال",
"وقالت",
"وقد",
"وقف",
"وكان",
"وكانت",
"ولا",
"ولم",
"ومن",
"وهو",
"وهي",
"يكون",
"يمكن",
"يوم",
};


char *stoplist_cs [] = {
"ahoj",
"ale",
"anebo",
"ano",
"asi",
"aspoň",
"ačkoli",
"bez",
"beze",
"blízko",
"bohužel",
"brzo",
"bude",
"budeme",
"budete",
"budeš",
"budou",
"budu",
"byl",
"byla",
"byli",
"bylo",
"byly",
"bys",
"během",
"chce",
"chceme",
"chcete",
"chceš",
"chci",
"chtít",
"chtějí",
"chut'",
"chuti",
"co",
"daleko",
"den",
"deset",
"devatenáct",
"devět",
"do",
"dobrý",
"docela",
"dva",
"dvacet",
"dvanáct",
"dvě",
"dál",
"dále",
"děkovat",
"děkujeme",
"děkuji",
"hodně",
"jak",
"jde",
"je",
"jeden",
"jedenáct",
"jedna",
"jedno",
"jednou",
"jedou",
"jeho",
"jejich",
"její",
"jemu",
"jen",
"jenom",
"jestli",
"jestliže",
"ještě",
"jich",
"jimi",
"jinak",
"jsem",
"jsi",
"jsme",
"jsou",
"jste",
"já",
"jí",
"jím",
"kam",
"kde",
"kdo",
"kdy",
"když",
"ke",
"kolik",
"kromě",
"která",
"které",
"který",
"kteří",
"kvůli",
"mají",
"mezi",
"mnou",
"mně",
"moc",
"mohl",
"mohou",
"moje",
"moji",
"možná",
"musí",
"my",
"má",
"málo",
"mám",
"máme",
"máte",
"máš",
"mé",
"mí",
"mít",
"mě",
"můj",
"může",
"na",
"nad",
"nade",
"naproti",
"naše",
"naši",
"ne",
"nebo",
"nebyl",
"nebyla",
"nebyli",
"nebyly",
"nedělají",
"nedělá",
"nedělám",
"neděláme",
"neděláte",
"neděláš",
"nejsi",
"nemají",
"nemáme",
"nemáte",
"neměl",
"není",
"nestačí",
"nevadí",
"než",
"nic",
"nich",
"nimi",
"nula",
"nám",
"námi",
"nás",
"náš",
"ním",
"ně",
"něco",
"nějak",
"někde",
"někdo",
"němu",
"od",
"ode",
"on",
"ona",
"oni",
"ono",
"ony",
"osm",
"osmnáct",
"pak",
"patnáct",
"po",
"potom",
"pozdě",
"pořád",
"pro",
"prostě",
"prosím",
"proti",
"protože",
"proč",
"pět",
"před",
"přes",
"přese",
"rovně",
"se",
"sedm",
"sedmnáct",
"skoro",
"smí",
"smějí",
"snad",
"spolu",
"sta",
"sto",
"sté",
"ta",
"tady",
"tak",
"takhle",
"taky",
"tam",
"tamhle",
"tamhleto",
"tamto",
"tebe",
"tebou",
"ted'",
"tedy",
"ten",
"ti",
"tisíc",
"tisíce",
"to",
"tobě",
"tohle",
"toto",
"trošku",
"tvoje",
"tvá",
"tvé",
"tvůj",
"ty",
"tě",
"třeba",
"tři",
"třináct",
"určitě",
"už",
"vaše",
"vaši",
"ve",
"vedle",
"večer",
"vlastně",
"vy",
"vám",
"vámi",
"vás",
"váš",
"všechno",
"všichni",
"vůbec",
"vždy",
"za",
"zatímco",
"zač",
"ze",
"čau",
"čtrnáct",
"čtyři",
"šest",
"šestnáct",
"že",
};


char *stoplist_ro [] = {
"acea",
"aceasta",
"această",
"aceea",
"acei",
"aceia",
"acel",
"acela",
"acele",
"acelea",
"acest",
"acesta",
"aceste",
"acestea",
"aceşti",
"aceştia",
"acolo",
"acord",
"acum",
"ai",
"aia",
"aibă",
"aici",
"al",
"ale",
"alea",
"altceva",
"altcineva",
"am",
"ar",
"are",
"asemenea",
"asta",
"astea",
"astăzi",
"asupra",
"au",
"avea",
"avem",
"aveţi",
"azi",
"aş",
"aşadar",
"aţi",
"bine",
"bucur",
"bună",
"ca",
"care",
"caut",
"ce",
"cel",
"ceva",
"chiar",
"cinci",
"cine",
"cineva",
"contra",
"cu",
"cum",
"cumva",
"curând",
"curînd",
"când",
"cât",
"câte",
"câtva",
"câţi",
"cînd",
"cît",
"cîte",
"cîtva",
"cîţi",
"că",
"căci",
"cărei",
"căror",
"cărui",
"către",
"da",
"dacă",
"dar",
"datorită",
"dată",
"dau",
"de",
"deci",
"deja",
"deoarece",
"departe",
"deşi",
"din",
"dinaintea",
"dintr-",
"dintre",
"doi",
"doilea",
"două",
"drept",
"după",
"dă",
"ea",
"ei",
"el",
"ele",
"eram",
"este",
"eu",
"eşti",
"face",
"fata",
"fi",
"fie",
"fiecare",
"fii",
"fim",
"fiu",
"fiţi",
"frumos",
"fără",
"graţie",
"halbă",
"iar",
"ieri",
"la",
"le",
"li",
"lor",
"lui",
"lângă",
"lîngă",
"mai",
"mea",
"mei",
"mele",
"mereu",
"meu",
"mi",
"mie",
"mine",
"mult",
"multă",
"mulţi",
"mulţumesc",
"mâine",
"mîine",
"mă",
"ne",
"nevoie",
"nici",
"nicăieri",
"nimeni",
"nimeri",
"nimic",
"nişte",
"noastre",
"noastră",
"noi",
"noroc",
"nostru",
"nouă",
"noştri",
"nu",
"opt",
"ori",
"oricare",
"orice",
"oricine",
"oricum",
"oricând",
"oricât",
"oricînd",
"oricît",
"oriunde",
"patra",
"patru",
"patrulea",
"pe",
"pentru",
"peste",
"pic",
"poate",
"pot",
"prea",
"prima",
"primul",
"prin",
"printr-",
"puţin",
"puţina",
"puţină",
"până",
"pînă",
"rog",
"sa",
"sale",
"sau",
"se",
"spate",
"spre",
"sub",
"sunt",
"suntem",
"sunteţi",
"sută",
"sînt",
"sîntem",
"sînteţi",
"să",
"săi",
"său",
"ta",
"tale",
"te",
"timp",
"tine",
"toate",
"toată",
"tot",
"totuşi",
"toţi",
"trei",
"treia",
"treilea",
"tu",
"tăi",
"tău",
"un",
"una",
"unde",
"undeva",
"unei",
"uneia",
"unele",
"uneori",
"unii",
"unor",
"unora",
"unu",
"unui",
"unuia",
"unul",
"vi",
"voastre",
"voastră",
"voi",
"vostru",
"vouă",
"voştri",
"vreme",
"vreo",
"vreun",
"vă",
"zece",
"zero",
"zi",
"zice",
"îi",
"îl",
"îmi",
"împotriva",
"în ",
"înainte",
"înaintea",
"încotro",
"încât",
"încît",
"între",
"întrucât",
"întrucît",
"îţi",
"ăla",
"ălea",
"ăsta",
"ăstea",
"ăştia",
"şapte",
"şase",
"şi",
"ştiu",
"ţi",
"ţie",
};


char *stoplist_bg [] = {
"а",
"автентичен",
"аз",
"ако",
"ала",
"бе",
"без",
"беше",
"би",
"бивш",
"бивша",
"бившо",
"бил",
"била",
"били",
"било",
"благодаря",
"близо",
"бъдат",
"бъде",
"бяха",
"в",
"вас",
"ваш",
"ваша",
"вероятно",
"вече",
"взема",
"ви",
"вие",
"винаги",
"внимава",
"време",
"все",
"всеки",
"всички",
"всичко",
"всяка",
"във",
"въпреки",
"върху",
"г",
"ги",
"главен",
"главна",
"главно",
"глас",
"го",
"година",
"години",
"годишен",
"д",
"да",
"дали",
"два",
"двама",
"двамата",
"две",
"двете",
"ден",
"днес",
"дни",
"до",
"добра",
"добре",
"добро",
"добър",
"докато",
"докога",
"дори",
"досега",
"доста",
"друг",
"друга",
"други",
"е",
"евтин",
"едва",
"един",
"една",
"еднаква",
"еднакви",
"еднакъв",
"едно",
"екип",
"ето",
"живот",
"за",
"забавям",
"зад",
"заедно",
"заради",
"засега",
"заспал",
"затова",
"защо",
"защото",
"и",
"из",
"или",
"им",
"има",
"имат",
"иска",
"й",
"каза",
"как",
"каква",
"какво",
"както",
"какъв",
"като",
"кога",
"когато",
"което",
"които",
"кой",
"който",
"колко",
"която",
"къде",
"където",
"към",
"лесен",
"лесно",
"ли",
"лош",
"м",
"май",
"малко",
"ме",
"между",
"мек",
"мен",
"месец",
"ми",
"много",
"мнозина",
"мога",
"могат",
"може",
"мокър",
"моля",
"момента",
"му",
"н",
"на",
"над",
"назад",
"най",
"направи",
"напред",
"например",
"нас",
"не",
"него",
"нещо",
"нея",
"ни",
"ние",
"никой",
"нито",
"нищо",
"но",
"нов",
"нова",
"нови",
"новина",
"някои",
"някой",
"няколко",
"няма",
"обаче",
"около",
"освен",
"особено",
"от",
"отгоре",
"отново",
"още",
"пак",
"по",
"повече",
"повечето",
"под",
"поне",
"поради",
"после",
"почти",
"прави",
"пред",
"преди",
"през",
"при",
"пък",
"първата",
"първи",
"първо",
"пъти",
"равен",
"равна",
"с",
"са",
"сам",
"само",
"се",
"сега",
"си",
"син",
"скоро",
"след",
"следващ",
"сме",
"смях",
"според",
"сред",
"срещу",
"сте",
"съм",
"със",
"също",
"т",
"т.н.",
"тази",
"така",
"такива",
"такъв",
"там",
"твой",
"те",
"тези",
"ти",
"то",
"това",
"тогава",
"този",
"той",
"толкова",
"точно",
"три",
"трябва",
"тук",
"тъй",
"тя",
"тях",
"у",
"утре",
"харесва",
"хиляди",
"ч",
"часа",
"че",
"често",
"чрез",
"ще",
"щом",
"юмрук",
"я",
"як",
};



char *stoplist_hu [] = {
"a",
"abba",
"abban",
"abból",
"addig",
"ahhoz",
"ahol",
"aki",
"akik",
"akkor",
"akár",
"alapján",
"alatt",
"alatta",
"alattad",
"alattam",
"alattatok",
"alattuk",
"alattunk",
"alá",
"alád",
"alájuk",
"alám",
"alánk",
"alátok",
"alól",
"alóla",
"alólad",
"alólam",
"alólatok",
"alóluk",
"alólunk",
"amely",
"amelybol",
"amelyek",
"amelyekben",
"amelyeket",
"amelyet",
"amelyik",
"amelynek",
"ami",
"amikor",
"amit",
"amott",
"amíg",
"annak",
"annál",
"arra",
"arról",
"attól",
"az",
"aznap",
"azok",
"azokat",
"azokba",
"azokban",
"azokból",
"azokhoz",
"azokig",
"azokkal",
"azokká",
"azoknak",
"azoknál",
"azokon",
"azokra",
"azokról",
"azoktól",
"azokért",
"azon",
"azonban",
"azonnal",
"azt",
"aztán",
"azzal",
"azzá",
"azért",
"bal",
"balra",
"ban",
"be",
"belé",
"beléd",
"beléjük",
"belém",
"belénk",
"belétek",
"belül",
"belőle",
"belőled",
"belőlem",
"belőletek",
"belőlük",
"belőlünk",
"ben",
"benne",
"benned",
"bennem",
"bennetek",
"bennük",
"bennünk",
"bár",
"bárcsak",
"bármilyen",
"búcsú",
"csak",
"csakhogy",
"csupán",
"de",
"dehogy",
"ebbe",
"ebben",
"ebből",
"eddig",
"egy",
"egyebek",
"egyebet",
"egyedül",
"egyelőre",
"egyet",
"egyik",
"egymás",
"egyre",
"egyszerre",
"egyéb",
"együtt",
"egész",
"egészen",
"ehhez",
"el",
"eleinte",
"ellen",
"ellenes",
"elleni",
"ellenére",
"elmondta",
"első",
"elsők",
"elsősorban",
"elsőt",
"elé",
"eléd",
"elég",
"eléjük",
"elém",
"elénk",
"elétek",
"előbb",
"elől",
"előle",
"előled",
"előlem",
"előletek",
"előlük",
"előlünk",
"először",
"előtt",
"előtte",
"előtted",
"előttem",
"előttetek",
"előttük",
"előttünk",
"előző",
"engem",
"ennek",
"ennyi",
"ennél",
"enyém",
"erre",
"erről",
"esetben",
"ettől",
"ez",
"ezek",
"ezekbe",
"ezekben",
"ezekből",
"ezeken",
"ezeket",
"ezekhez",
"ezekig",
"ezekkel",
"ezekké",
"ezeknek",
"ezeknél",
"ezekre",
"ezekről",
"ezektől",
"ezekért",
"ezen",
"ezentúl",
"ezer",
"ezret",
"ezt",
"ezután",
"ezzel",
"ezzé",
"ezért",
"fel",
"fele",
"felek",
"felet",
"felett",
"felé",
"fent",
"fenti",
"fél",
"fölé",
"gyakran",
"ha",
"halló",
"hamar",
"hanem",
"harmadik",
"harmadikat",
"harminc",
"hat",
"hatodik",
"hatodikat",
"hatot",
"hatvan",
"helyett",
"hetedik",
"hetediket",
"hetet",
"hetven",
"hirtelen",
"hiszen",
"hiába",
"hogy",
"hol",
"holnap",
"holnapot",
"honnan",
"hova",
"hozzá",
"hozzád",
"hozzájuk",
"hozzám",
"hozzánk",
"hozzátok",
"hurrá",
"huszadik",
"hány",
"hányszor",
"hármat",
"három",
"hát",
"hátha",
"hátulsó",
"hét",
"húsz",
"ide-оda",
"idén",
"igazán",
"igen",
"illetve",
"ilyen",
"immár",
"inkább",
"is",
"ismét",
"itt",
"jelenleg",
"jobban",
"jobbra",
"jó",
"jól",
"jólesik",
"jóval",
"jövőre",
"kell",
"kellene",
"kellett",
"kelljen",
"ketten",
"kettő",
"kettőt",
"kevés",
"ki",
"kiben",
"kiből",
"kicsit",
"kicsoda",
"kihez",
"kik",
"kikbe",
"kikben",
"kikből",
"kiken",
"kiket",
"kikhez",
"kikkel",
"kikké",
"kiknek",
"kiknél",
"kikre",
"kikről",
"kiktől",
"kikért",
"kilenc",
"kilencedik",
"kilencediket",
"kilencet",
"kilencven",
"kin",
"kinek",
"kinél",
"kire",
"kiről",
"kit",
"kitől",
"kivel",
"kivé",
"kié",
"kiért",
"korábban",
"képest",
"kérem",
"kérlek",
"kész",
"késő",
"később",
"későn",
"két",
"kétszer",
"körül",
"köszönhetően",
"köszönöm",
"közben",
"közel",
"közepesen",
"közepén",
"közé",
"között",
"közül",
"külön",
"különben",
"különböző",
"különbözőbb",
"különbözőek",
"lassan",
"le",
"legalább",
"legyen",
"lehet",
"lehetetlen",
"lehetőleg",
"lehetőség",
"lenne",
"lennék",
"lennének",
"lesz",
"leszek",
"lesznek",
"leszünk",
"lett",
"lettek",
"lettem",
"lettünk",
"lévő",
"ma",
"maga",
"magad",
"magam",
"magatokat",
"magukat",
"magunkat",
"magát",
"mai",
"majd",
"majdnem",
"manapság",
"meg",
"megcsinál",
"megcsinálnak",
"megint",
"megvan",
"mellett",
"mellette",
"melletted",
"mellettem",
"mellettetek",
"mellettük",
"mellettünk",
"mellé",
"melléd",
"melléjük",
"mellém",
"mellénk",
"mellétek",
"mellől",
"mellőle",
"mellőled",
"mellőlem",
"mellőletek",
"mellőlük",
"mellőlünk",
"melyik",
"mennyi",
"mert",
"mi",
"miatt",
"miatta",
"miattad",
"miattam",
"miattatok",
"miattuk",
"miattunk",
"mibe",
"miben",
"miből",
"mihez",
"mik",
"mikbe",
"mikben",
"mikből",
"miken",
"miket",
"mikhez",
"mikkel",
"mikké",
"miknek",
"miknél",
"mikor",
"mikre",
"mikről",
"miktől",
"mikért",
"milyen",
"min",
"mind",
"mindegyik",
"mindegyiket",
"minden",
"mindenesetre",
"mindenki",
"mindent",
"mindenütt",
"mindig",
"mindketten",
"minek",
"minket",
"mint",
"minél",
"mire",
"miről",
"mit",
"mitől",
"mivel",
"mivé",
"miért",
"mondta",
"most",
"mostanáig",
"már",
"más",
"másik",
"másikat",
"másnap",
"második",
"másodszor",
"mások",
"másokat",
"mást",
"még",
"mégis",
"míg",
"mögé",
"mögéd",
"mögéjük",
"mögém",
"mögénk",
"mögétek",
"mögött",
"mögötte",
"mögötted",
"mögöttem",
"mögöttetek",
"mögöttük",
"mögöttünk",
"mögül",
"mögüle",
"mögüled",
"mögülem",
"mögületek",
"mögülük",
"mögülünk",
"múltkor",
"múlva",
"na",
"nagyon",
"naponta",
"napot",
"ne",
"negyedik",
"negyediket",
"negyven",
"neked",
"nekem",
"neki",
"nekik",
"nektek",
"nekünk",
"nem",
"nemcsak",
"nemrég",
"nincs",
"nyolc",
"nyolcadik",
"nyolcadikat",
"nyolcat",
"nyolcvan",
"nála",
"nálad",
"nálam",
"nálatok",
"náluk",
"nálunk",
"négy",
"négyet",
"néha",
"néhány",
"nélkül",
"olyan",
"onnan",
"ott",
"pedig",
"persze",
"pár",
"például",
"rajta",
"rajtad",
"rajtam",
"rajtatok",
"rajtuk",
"rajtunk",
"rendben",
"rosszul",
"rá",
"rád",
"rájuk",
"rám",
"ránk",
"rátok",
"régen",
"régóta",
"részére",
"róla",
"rólad",
"rólam",
"rólatok",
"róluk",
"rólunk",
"rögtön",
"se",
"sem",
"semmi",
"semmilyen",
"semmiség",
"senki",
"soha",
"sok",
"sokan",
"sokszor",
"sokáig",
"során",
"stb.",
"szemben",
"szerbusz",
"szerint",
"szerinte",
"szerinted",
"szerintem",
"szerintetek",
"szerintük",
"szerintünk",
"szervusz",
"szinte",
"számára",
"száz",
"századik",
"százat",
"szépen",
"szíves",
"szívesen",
"szíveskedjék",
"sőt",
"talán",
"tavaly",
"te",
"tegnap",
"tegnapelőtt",
"tehát",
"tele",
"tessék",
"ti",
"tied",
"titeket",
"tizedik",
"tizediket",
"tizenegy",
"tizenegyedik",
"tizenhat",
"tizenhárom",
"tizenhét",
"tizenkettedik",
"tizenkettő",
"tizenkilenc",
"tizenkét",
"tizennyolc",
"tizennégy",
"tizenöt",
"tizet",
"tovább",
"további",
"távol",
"téged",
"tényleg",
"tíz",
"több",
"többi",
"többször",
"túl",
"tőle",
"tőled",
"tőlem",
"tőletek",
"tőlük",
"tőlünk",
"ugyanakkor",
"ugyanez",
"ugyanis",
"ugye",
"urak",
"uram",
"urat",
"utoljára",
"utolsó",
"után",
"vagy",
"vagyis",
"vagyok",
"vagytok",
"vagyunk",
"vajon",
"valahol",
"valaki",
"valakit",
"valamelyik",
"valami",
"valamint",
"van",
"vannak",
"vele",
"veled",
"velem",
"veletek",
"velük",
"velünk",
"viszlát",
"viszont",
"viszontlátásra",
"volna",
"volnának",
"volnék",
"volt",
"voltak",
"voltam",
"voltunk",
"végre",
"végén",
"végül",
"által",
"általában",
"ám",
"át",
"éljen",
"én",
"érte",
"érted",
"értem",
"értetek",
"értük",
"értünk",
"és",
"év",
"évben",
"éve",
"évek",
"éves",
"évi",
"évvel",
"így",
"óta",
"ön",
"önbe",
"önben",
"önből",
"önhöz",
"önnek",
"önnel",
"önnél",
"önre",
"önről",
"önt",
"öntől",
"önért",
"önök",
"önökbe",
"önökben",
"önökből",
"önöket",
"önökhöz",
"önökkel",
"önöknek",
"önöknél",
"önökre",
"önökről",
"önöktől",
"önökért",
"önökön",
"önön",
"öt",
"ötven",
"ötödik",
"ötödiket",
"ötöt",
"úgy",
"úgyis",
"úgynevezett",
"újra",
"úr",
"ő",
"ők",
"őket",
"őt",
};


char *stoplist_ru [] = {
"а",
"алло",
"без",
"близко",
"более",
"больше",
"будем",
"будет",
"будете",
"будешь",
"будто",
"буду",
"будут",
"будь",
"бы",
"бывает",
"бывь",
"был",
"была",
"были",
"было",
"быть",
"в",
"важная",
"важное",
"важные",
"важный",
"вам",
"вами",
"вас",
"ваш",
"ваша",
"ваше",
"ваши",
"вверх",
"вдали",
"вдруг",
"ведь",
"везде",
"весь",
"вниз",
"внизу",
"во",
"вокруг",
"вон",
"восемнадцатый",
"восемнадцать",
"восемь",
"восьмой",
"вот",
"впрочем",
"времени",
"время",
"все",
"всегда",
"всего",
"всем",
"всеми",
"всему",
"всех",
"всею",
"всю",
"всюду",
"вся",
"всё",
"второй",
"вы",
"г",
"где",
"говорил",
"говорит",
"год",
"года",
"году",
"да",
"давно",
"даже",
"далеко",
"дальше",
"даром",
"два",
"двадцатый",
"двадцать",
"две",
"двенадцатый",
"двенадцать",
"двух",
"девятнадцатый",
"девятнадцать",
"девятый",
"девять",
"действительно",
"дел",
"день",
"десятый",
"десять",
"для",
"до",
"довольно",
"долго",
"должно",
"другая",
"другие",
"других",
"друго",
"другое",
"другой",
"е",
"его",
"ее",
"ей",
"ему",
"если",
"есть",
"еще",
"ещё",
"ею",
"её",
"ж",
"же",
"жизнь",
"за",
"занят",
"занята",
"занято",
"заняты",
"затем",
"зато",
"зачем",
"здесь",
"значит",
"и",
"из",
"или",
"им",
"именно",
"иметь",
"ими",
"имя",
"иногда",
"их",
"к",
"каждая",
"каждое",
"каждые",
"каждый",
"кажется",
"как",
"какая",
"какой",
"кем",
"когда",
"кого",
"ком",
"кому",
"конечно",
"которая",
"которого",
"которой",
"которые",
"который",
"которых",
"кроме",
"кругом",
"кто",
"куда",
"лет",
"ли",
"лишь",
"лучше",
"люди",
"м",
"мало",
"между",
"меля",
"менее",
"меньше",
"меня",
"миллионов",
"мимо",
"мира",
"мне",
"много",
"многочисленная",
"многочисленное",
"многочисленные",
"многочисленный",
"мной",
"мною",
"мог",
"могут",
"мож",
"может",
"можно",
"можхо",
"мои",
"мой",
"мор",
"мочь",
"моя",
"моё",
"мы",
"на",
"наверху",
"над",
"надо",
"назад",
"наиболее",
"наконец",
"нам",
"нами",
"нас",
"начала",
"наш",
"наша",
"наше",
"наши",
"не",
"него",
"недавно",
"недалеко",
"нее",
"ней",
"нельзя",
"нем",
"немного",
"нему",
"непрерывно",
"нередко",
"несколько",
"нет",
"нею",
"неё",
"ни",
"нибудь",
"ниже",
"низко",
"никогда",
"никуда",
"ними",
"них",
"ничего",
"но",
"ну",
"нужно",
"нх",
"о",
"об",
"оба",
"обычно",
"один",
"одиннадцатый",
"одиннадцать",
"однажды",
"однако",
"одного",
"одной",
"около",
"он",
"она",
"они",
"оно",
"опять",
"особенно",
"от",
"отовсюду",
"отсюда",
"очень",
"первый",
"перед",
"по",
"под",
"пожалуйста",
"позже",
"пока",
"пор",
"пора",
"после",
"посреди",
"потом",
"потому",
"почему",
"почти",
"прекрасно",
"при",
"про",
"просто",
"против",
"процентов",
"пятнадцатый",
"пятнадцать",
"пятый",
"пять",
"раз",
"разве",
"рано",
"раньше",
"рядом",
"с",
"сам",
"сама",
"сами",
"самим",
"самими",
"самих",
"само",
"самого",
"самой",
"самом",
"самому",
"саму",
"свое",
"своего",
"своей",
"свои",
"своих",
"свою",
"сеаой",
"себе",
"себя",
"сегодня",
"седьмой",
"сейчас",
"семнадцатый",
"семнадцать",
"семь",
"сих",
"сказал",
"сказала",
"сказать",
"сколько",
"слишком",
"сначала",
"снова",
"со",
"собой",
"собою",
"совсем",
"спасибо",
"стал",
"суть",
"т",
"та",
"так",
"такая",
"также",
"такие",
"такое",
"такой",
"там",
"твой",
"твоя",
"твоё",
"те",
"тебе",
"тебя",
"тем",
"теми",
"теперь",
"тех",
"то",
"тобой",
"тобою",
"тогда",
"того",
"тоже",
"только",
"том",
"тому",
"тот",
"тою",
"третий",
"три",
"тринадцатый",
"тринадцать",
"ту",
"туда",
"тут",
"ты",
"тысяч",
"у",
"уж",
"уже",
"уметь",
"хорошо",
"хотеть",
"хоть",
"хотя",
"хочешь",
"часто",
"чаще",
"чего",
"человек",
"чем",
"чему",
"через",
"четвертый",
"четыре",
"четырнадцатый",
"четырнадцать",
"что",
"чтоб",
"чтобы",
"чуть",
"шестнадцатый",
"шестнадцать",
"шестой",
"шесть",
"эта",
"эти",
"этим",
"этими",
"этих",
"это",
"этого",
"этой",
"этом",
"этому",
"этот",
"эту",
"я",
};



char *stoplist_sv [] = {
"aderton",
"adertonde",
"adjö",
"aldrig",
"alla",
"allas",
"allt",
"alltid",
"alltså",
"andra",
"andras",
"annan",
"annat",
"artonde",
"artonn",
"att",
"av",
"bakom",
"bara",
"behöva",
"behövas",
"behövde",
"behövt",
"beslut",
"beslutat",
"beslutit",
"bland",
"blev",
"bli",
"blir",
"blivit",
"bort",
"borta",
"bra",
"bäst",
"bättre",
"båda",
"bådas",
"dag",
"dagar",
"dagarna",
"dagen",
"de",
"del",
"delen",
"dem",
"den",
"deras",
"dess",
"det",
"detta",
"dig",
"din",
"dina",
"dit",
"ditt",
"dock",
"du",
"där",
"därför",
"då",
"efter",
"eftersom",
"elfte",
"eller",
"elva",
"en",
"enkel",
"enkelt",
"enkla",
"enligt",
"er",
"era",
"ert",
"ett",
"ettusen",
"fanns",
"fem",
"femte",
"femtio",
"femtionde",
"femton",
"femtonde",
"fick",
"fin",
"finnas",
"finns",
"fjorton",
"fjortonde",
"fjärde",
"fler",
"flera",
"flesta",
"fram",
"framför",
"från",
"fyra",
"fyrtio",
"fyrtionde",
"få ",
"får",
"fått ",
"följande",
"för",
"före",
"förlåt",
"förra",
"första",
"genast",
"genom",
"gick",
"gjorde",
"gjort",
"god",
"goda",
"godare",
"godast",
"gott",
"gälla",
"gäller",
"gällt",
"gärna",
"gå",
"går",
"gått",
"gör",
"göra",
"ha",
"hade",
"haft",
"han",
"hans",
"har",
"heller",
"hellre",
"helst",
"helt",
"henne",
"hennes",
"hit",
"hon",
"honom",
"hundra",
"hundraen",
"hundraett",
"hur",
"här",
"hög",
"höger",
"högre",
"högst",
"i",
"ibland",
"idag",
"igen",
"igår",
"imorgon",
"in",
"inför",
"inga",
"ingen",
"ingenting",
"inget",
"innan",
"inne",
"inom",
"inte",
"inuti",
"ja",
"jag",
"jämfört",
"kan",
"kanske",
"knappast",
"kom",
"komma",
"kommer",
"kommit",
"kr",
"kunde",
"kunna",
"kunnat",
"kvar",
"legat",
"ligga",
"ligger",
"lika",
"likställd",
"likställda",
"lilla",
"lite",
"liten",
"litet",
"länge",
"längre",
"längst",
"lätt",
"lättare",
"lättast",
"långsam",
"långsammare",
"långsammast",
"långsamt",
"långt",
"man",
"med",
"mellan",
"men",
"mer",
"mera",
"mest",
"mig",
"min",
"mina",
"mindre",
"minst",
"mitt",
"mittemot",
"mot",
"mycket",
"många",
"måste",
"möjlig",
"möjligen",
"möjligt",
"möjligtvis",
"ned",
"nederst",
"nedersta",
"nedre",
"nej",
"ner",
"ni",
"nio",
"nionde",
"nittio",
"nittionde",
"nitton",
"nittonde",
"nog",
"noll",
"nr",
"nu",
"nummer",
"när",
"nästa",
"någon",
"någonting",
"något",
"några",
"nödvändig",
"nödvändiga",
"nödvändigt",
"nödvändigtvis",
"och",
"också",
"ofta",
"oftast",
"olika",
"olikt",
"om",
"oss",
"på",
"rakt",
"redan",
"rätt",
"sade",
"sagt",
"samma",
"sedan",
"senare",
"senast",
"sent",
"sex",
"sextio",
"sextionde",
"sexton",
"sextonde",
"sig",
"sin",
"sina",
"sist",
"sista",
"siste",
"sitt",
"sju",
"sjunde",
"sjuttio",
"sjuttionde",
"sjutton",
"sjuttonde",
"sjätte",
"ska",
"skall",
"skulle",
"slutligen",
"små",
"smått",
"snart",
"som",
"stor",
"stora",
"stort",
"större",
"störst",
"säga",
"säger",
"sämre",
"sämst",
"så",
"tack",
"tidig",
"tidigare",
"tidigast",
"tidigt",
"till",
"tills",
"tillsammans",
"tio",
"tionde",
"tjugo",
"tjugoen",
"tjugoett",
"tjugonde",
"tjugotre",
"tjugotvå",
"tjungo",
"tolfte",
"tolv",
"tre",
"tredje",
"trettio",
"trettionde",
"tretton",
"trettonde",
"två",
"tvåhundra",
"under",
"upp",
"ur",
"ursäkt",
"ut",
"utan",
"utanför",
"ute",
"vad",
"var",
"vara",
"varför",
"varifrån",
"varit",
"varken",
"varsågod",
"vart",
"vem",
"vems",
"verkligen",
"vi",
"vid",
"vidare",
"viktig",
"viktigare",
"viktigast",
"viktigt",
"vilka",
"vilken",
"vilket",
"vill",
"vänster",
"vänstra",
"värre",
"vår",
"våra",
"vårt",
"än",
"ännu",
"även",
"åtminstone",
"åtta",
"åttio",
"åttionde",
"åttonde",
"över",
"övermorgon",
"överst",
"övre",
};


char *stoplist_fi [] = {
"aiemmin",
"aika",
"aikaa",
"aikaan",
"aikaisemmin",
"aikaisin",
"aikajen",
"aikana",
"aikoina",
"aikoo",
"aikovat",
"aina",
"ainakaan",
"ainakin",
"ainoa",
"ainoat",
"aiomme",
"aion",
"aiotte",
"aist",
"aivan",
"ajan",
"alas",
"alemmas",
"alkuisin",
"alkuun",
"alla",
"alle",
"aloitamme",
"aloitan",
"aloitat",
"aloitatte",
"aloitattivat",
"aloitettava",
"aloitettevaksi",
"aloitettu",
"aloitimme",
"aloitin",
"aloitit",
"aloititte",
"aloittaa",
"aloittamatta",
"aloitti",
"aloittivat",
"alta",
"aluksi",
"alussa",
"alusta",
"annettavaksi",
"annetteva",
"annettu",
"antaa",
"antamatta",
"antoi",
"aoua",
"apu",
"asia",
"asiaa",
"asian",
"asiasta",
"asiat",
"asioiden",
"asioihin",
"asioita",
"asti",
"avuksi",
"avulla",
"avun",
"avutta",
"edelle",
"edelleen",
"edellä",
"edeltä",
"edemmäs",
"edes",
"edessä",
"edestä",
"ehkä",
"ei",
"eikä",
"eilen",
"eivät",
"eli",
"ellei",
"elleivät",
"ellemme",
"ellen",
"ellet",
"ellette",
"emme",
"en",
"enemmän",
"eniten",
"ennen",
"ensi",
"ensimmäinen",
"ensimmäiseksi",
"ensimmäisen",
"ensimmäisenä",
"ensimmäiset",
"ensimmäisiksi",
"ensimmäisinä",
"ensimmäisiä",
"ensimmäistä",
"ensin",
"entinen",
"entisen",
"entisiä",
"entisten",
"entistä",
"enää",
"eri",
"erittäin",
"erityisesti",
"eräiden",
"eräs",
"eräät",
"esi",
"esiin",
"esillä",
"esimerkiksi",
"et",
"eteen",
"etenkin",
"ette",
"ettei",
"että",
"halua",
"haluaa",
"haluamatta",
"haluamme",
"haluan",
"haluat",
"haluatte",
"haluavat",
"halunnut",
"halusi",
"halusimme",
"halusin",
"halusit",
"halusitte",
"halusivat",
"halutessa",
"haluton",
"he",
"hei",
"heidän",
"heihin",
"heille",
"heiltä",
"heissä",
"heistä",
"heitä",
"helposti",
"heti",
"hetkellä",
"hieman",
"huolimatta",
"huomenna",
"hyvien",
"hyviin",
"hyviksi",
"hyville",
"hyviltä",
"hyvin",
"hyvinä",
"hyvissä",
"hyvistä",
"hyviä",
"hyvä",
"hyvät",
"hyvää",
"hän",
"häneen",
"hänelle",
"hänellä",
"häneltä",
"hänen",
"hänessä",
"hänestä",
"hänet",
"ihan",
"ilman",
"ilmeisesti",
"itse",
"itsensä",
"itseään",
"ja",
"jo",
"johon",
"joiden",
"joihin",
"joiksi",
"joilla",
"joille",
"joilta",
"joissa",
"joista",
"joita",
"joka",
"jokainen",
"jokin",
"joko",
"joku",
"jolla",
"jolle",
"jolloin",
"jolta",
"jompikumpi",
"jonka",
"jonkin",
"jonne",
"joo",
"jopa",
"jos",
"joskus",
"jossa",
"josta",
"jota",
"jotain",
"joten",
"jotenkin",
"jotenkuten",
"jotka",
"jotta",
"jouduimme",
"jouduin",
"jouduit",
"jouduitte",
"joudumme",
"joudun",
"joudutte",
"joukkoon",
"joukossa",
"joukosta",
"joutua",
"joutui",
"joutuivat",
"joutumaan",
"joutuu",
"joutuvat",
"juuri",
"jälkeen",
"jälleen",
"jää",
"kahdeksan",
"kahdeksannen",
"kahdella",
"kahdelle",
"kahdelta",
"kahden",
"kahdessa",
"kahdesta",
"kahta",
"kahteen",
"kai",
"kaiken",
"kaikille",
"kaikilta",
"kaikkea",
"kaikki",
"kaikkia",
"kaikkiaan",
"kaikkialla",
"kaikkialle",
"kaikkialta",
"kaikkien",
"kaikkin",
"kaksi",
"kannalta",
"kannattaa",
"kanssa",
"kanssaan",
"kanssamme",
"kanssani",
"kanssanne",
"kanssasi",
"kauan",
"kauemmas",
"kautta",
"kehen",
"keiden",
"keihin",
"keiksi",
"keille",
"keillä",
"keiltä",
"keinä",
"keissä",
"keistä",
"keitten",
"keittä",
"keitä",
"keneen",
"keneksi",
"kenelle",
"kenellä",
"keneltä",
"kenen",
"kenenä",
"kenessä",
"kenestä",
"kenet",
"kenettä",
"kennessästä",
"kerran",
"kerta",
"kertaa",
"kesken",
"keskimäärin",
"ketkä",
"ketä",
"kiitos",
"kohti",
"koko",
"kokonaan",
"kolmas",
"kolme",
"kolmen",
"kolmesti",
"koska",
"koskaan",
"kovin",
"kuin",
"kuinka",
"kuitenkaan",
"kuitenkin",
"kuka",
"kukaan",
"kukin",
"kumpainen",
"kumpainenkaan",
"kumpi",
"kumpikaan",
"kumpikin",
"kun",
"kuten",
"kuuden",
"kuusi",
"kuutta",
"kyllä",
"kymmenen",
"kyse",
"liian",
"liki",
"lisäksi",
"lisää",
"luo",
"lähekkäin",
"lähelle",
"lähellä",
"läheltä",
"lähemmäs",
"lähes",
"lähinnä",
"lähtien",
"läpi",
"mahdollisimman",
"mahdollista",
"me",
"meidän",
"meille",
"meillä",
"melkein",
"melko",
"menee",
"meneet",
"menemme",
"menen",
"menet",
"menette",
"menevät",
"meni",
"menimme",
"menin",
"menit",
"menivät",
"mennessä",
"mennyt",
"menossa",
"mihin",
"mikin",
"miksi",
"mikä",
"mikäli",
"mikään",
"milloin",
"minne",
"minun",
"minut",
"minä",
"missä",
"mistä",
"miten",
"mitä",
"mitään",
"moi",
"molemmat",
"mones",
"monesti",
"monet",
"moni",
"moniaalla",
"moniaalle",
"moniaalta",
"monta",
"muassa",
"muiden",
"muita",
"muka",
"mukaan",
"mukaansa",
"mukana",
"mutta",
"muu",
"muualla",
"muualle",
"muualta",
"muuanne",
"muulloin",
"muun",
"muut",
"muuta",
"muutama",
"muutaman",
"muuten",
"myöhemmin",
"myös",
"myöskin",
"myöskään",
"myötä",
"ne",
"neljä",
"neljän",
"neljää",
"niiden",
"niin",
"niistä",
"niitä",
"noin",
"nopeammin",
"nopeasti",
"nopeiten",
"nro",
"nuo",
"nyt",
"näiden",
"näin",
"näissä",
"näissähin",
"näissälle",
"näissältä",
"näissästä",
"näitä",
"nämä",
"ohi",
"oikein",
"ole",
"olemme",
"olen",
"olet",
"olette",
"oleva",
"olevan",
"olevat",
"oli",
"olimme",
"olin",
"olisi",
"olisimme",
"olisin",
"olisit",
"olisitte",
"olisivat",
"olit",
"olitte",
"olivat",
"olla",
"olleet",
"olli",
"ollut",
"oma",
"omaa",
"omaan",
"omaksi",
"omalle",
"omalta",
"oman",
"omassa",
"omat",
"omia",
"omien",
"omiin",
"omiksi",
"omille",
"omilta",
"omissa",
"omista",
"on",
"onkin",
"onko",
"ovat",
"paikoittain",
"paitsi",
"pakosti",
"paljon",
"paremmin",
"parempi",
"parhaillaan",
"parhaiten",
"perusteella",
"peräti",
"pian",
"pieneen",
"pieneksi",
"pienelle",
"pienellä",
"pieneltä",
"pienempi",
"pienestä",
"pieni",
"pienin",
"puolesta",
"puolestaan",
"päälle",
"runsaasti",
"saakka",
"sadam",
"sama",
"samaa",
"samaan",
"samalla",
"samallalta",
"samallassa",
"samallasta",
"saman",
"samat",
"samoin",
"sata",
"sataa",
"satojen",
"se",
"seitsemän",
"sekä",
"sen",
"seuraavat",
"siellä",
"sieltä",
"siihen",
"siinä",
"siis",
"siitä",
"sijaan",
"siksi",
"silloin",
"sillä",
"silti",
"sinne",
"sinua",
"sinulle",
"sinulta",
"sinun",
"sinussa",
"sinusta",
"sinut",
"sinä",
"sisäkkäin",
"sisällä",
"siten",
"sitten",
"sitä",
"suoraan",
"suuntaan",
"suuren",
"suuret",
"suuri",
"suuria",
"suurin",
"suurten",
"taa",
"taas",
"taemmas",
"tahansa",
"tai",
"takaa",
"takaisin",
"takana",
"takia",
"tapauksessa",
"tavalla",
"tavoitteena",
"te",
"tietysti",
"todella",
"toinen",
"toisaalla",
"toisaalle",
"toisaalta",
"toiseen",
"toiseksi",
"toisella",
"toiselle",
"toiselta",
"toisemme",
"toisen",
"toisensa",
"toisessa",
"toisesta",
"toista",
"toistaiseksi",
"toki",
"tosin",
"tuhannen",
"tuhat",
"tule",
"tulee",
"tulemme",
"tulen",
"tulet",
"tulette",
"tulevat",
"tulimme",
"tulin",
"tulisi",
"tulisimme",
"tulisin",
"tulisit",
"tulisitte",
"tulisivat",
"tulit",
"tulitte",
"tulivat",
"tulla",
"tulleet",
"tullut",
"tuntuu",
"tuo",
"tuolla",
"tuolloin",
"tuolta",
"tuonne",
"tuskin",
"tykö",
"tähän",
"tällä",
"tällöin",
"tämä",
"tämän",
"tänne",
"tänä",
"tänään",
"tässä",
"tästä",
"täten",
"tätä",
"täysin",
"täytyvät",
"täytyy",
"täällä",
"täältä",
"usea",
"useasti",
"useimmiten",
"usein",
"useita",
"uudeksi",
"uudelleen",
"uuden",
"uudet",
"uusi",
"uusia",
"uusien",
"uusinta",
"uuteen",
"uutta",
"vaan",
"vai",
"vaiheessa",
"vaikea",
"vaikean",
"vaikeat",
"vaikeilla",
"vaikeille",
"vaikeilta",
"vaikeissa",
"vaikeista",
"vaikka",
"vain",
"varmasti",
"varsin",
"varsinkin",
"varten",
"vasta",
"vastaan",
"vastakkain",
"verran",
"vielä",
"vierekkäin",
"vieri",
"viiden",
"viime",
"viimeinen",
"viimeisen",
"viimeksi",
"viisi",
"voi",
"voidaan",
"voimme",
"voin",
"voisi",
"voit",
"voitte",
"voivat",
"vuoden",
"vuoksi",
"vuosi",
"vuosien",
"vuosina",
"vuotta",
"vähemmän",
"vähintään",
"vähiten",
"vähän",
"välillä",
"yhdeksän",
"yhden",
"yhdessä",
"yhteen",
"yhteensä",
"yhteydessä",
"yhteyteen",
"yhtä",
"yhtäälle",
"yhtäällä",
"yhtäältä",
"yhtään",
"yhä",
"yksi",
"yksin",
"yksittäin",
"yleensä",
"ylemmäs",
"yli",
"ylös",
"ympäri",
"älköön",
"älä",
};


char *stoplist_pt [] = {
"a",
"adeus",
"agora",
"ainda",
"algo",
"algumas",
"alguns",
"ali",
"além",
"ano",
"anos",
"antes",
"ao",
"aos",
"apenas",
"apoio",
"após",
"aquela",
"aquelas",
"aquele",
"aqueles",
"aqui",
"aquilo",
"as",
"assim",
"através",
"atrás",
"até",
"aí",
"baixo",
"bastante",
"bem",
"bom",
"breve",
"cada",
"catorze",
"cedo",
"cento",
"certamente",
"certeza",
"cima",
"cinco",
"coisa",
"com",
"como",
"conselho",
"contra",
"custa",
"cá",
"da",
"daquela",
"daquele",
"dar",
"das",
"de",
"debaixo",
"demais",
"dentro",
"depois",
"desde",
"dessa",
"desse",
"desta",
"deste",
"deve",
"deverá",
"dez",
"dezanove",
"dezasseis",
"dezassete",
"dezoito",
"dia",
"diante",
"diz",
"dizem",
"dizer",
"do",
"dois",
"dos",
"doze",
"duas",
"dá",
"dão",
"dúvida",
"e",
"ela",
"elas",
"ele",
"eles",
"em",
"embora",
"entre",
"era",
"essa",
"essas",
"esse",
"esses",
"esta",
"estar",
"estas",
"estava",
"este",
"estes",
"esteve",
"estive",
"estivemos",
"estiveram",
"estiveste",
"estivestes",
"estou",
"está",
"estás",
"eu",
"exemplo",
"falta",
"favor",
"faz",
"fazeis",
"fazem",
"fazemos",
"fazer",
"fazes",
"faço",
"fez",
"fim",
"final",
"foi",
"fomos",
"for",
"foram",
"forma",
"foste",
"fostes",
"fui",
"geral",
"grande",
"grandes",
"grupo",
"hoje",
"horas",
"há",
"isso",
"isto",
"já",
"lado",
"local",
"logo",
"longe",
"lugar",
"lá",
"maior",
"maioria",
"mais",
"mal",
"mas",
"me",
"meio",
"menor",
"menos",
"meses",
"meu",
"meus",
"mil",
"minha",
"minhas",
"momento",
"muito",
"muitos",
"máximo",
"mês",
"na",
"nada",
"naquela",
"naquele",
"nas",
"nem",
"nenhuma",
"nessa",
"nesse",
"nesta",
"neste",
"no",
"noite",
"nome",
"nos",
"nossa",
"nossas",
"nosso",
"nossos",
"nova",
"nove",
"novo",
"novos",
"num",
"numa",
"nunca",
"não",
"nível",
"nós",
"número",
"o",
"obra",
"obrigada",
"obrigado",
"oitava",
"oitavo",
"oito",
"onde",
"ontem",
"onze",
"os",
"ou",
"outra",
"outras",
"outro",
"outros",
"para",
"parece",
"parte",
"partir",
"pela",
"pelas",
"pelo",
"pelos",
"perto",
"pode",
"podem",
"poder",
"ponto",
"pontos",
"por",
"porque",
"porquê",
"posição",
"possivelmente",
"posso",
"possível",
"pouca",
"pouco",
"primeira",
"primeiro",
"próprio",
"próximo",
"puderam",
"pôde",
"põe",
"põem",
"qual",
"quando",
"quanto",
"quarta",
"quarto",
"quatro",
"que",
"quem",
"quer",
"quero",
"questão",
"quinta",
"quinto",
"quinze",
"quê",
"relação",
"sabe",
"se",
"segunda",
"segundo",
"sei",
"seis",
"sem",
"sempre",
"ser",
"seria",
"sete",
"seu",
"seus",
"sexta",
"sexto",
"sim",
"sistema",
"sob",
"sobre",
"sois",
"somos",
"sou",
"sua",
"suas",
"são",
"sétima",
"sétimo",
"tal",
"talvez",
"também",
"tanto",
"tarde",
"te",
"tem",
"temos",
"tendes",
"tenho",
"tens",
"ter",
"terceira",
"terceiro",
"teu",
"teus",
"teve",
"tive",
"tivemos",
"tiveram",
"tiveste",
"tivestes",
"toda",
"todas",
"todo",
"todos",
"trabalho",
"treze",
"três",
"tu",
"tua",
"tuas",
"tudo",
"tão",
"têm",
"um",
"uma",
"umas",
"uns",
"vai",
"vais",
"vem",
"vens",
"ver",
"vez",
"vezes",
"viagem",
"vindo",
"vinte",
"você",
"vocês",
"vos",
"vossa",
"vossas",
"vosso",
"vossos",
"vários",
"vão",
"vêm",
"vós",
"zero",
"à",
"às",
"área",
"é",
"és",
};


char *stoplist_es [] = {
"a",
"actualmente",
"adelante",
"además",
"afirmó",
"agregó",
"ahora",
"ahí",
"al",
"algo",
"alguna",
"algunas",
"alguno",
"algunos",
"algún",
"alrededor",
"ambos",
"ante",
"anterior",
"antes",
"apenas",
"aproximadamente",
"aquí",
"aseguró",
"así",
"aunque",
"ayer",
"añadió",
"aún",
"bajo",
"bien",
"buen",
"buena",
"buenas",
"bueno",
"buenos",
"cada",
"casi",
"cerca",
"cierto",
"cinco",
"comentó",
"como",
"con",
"conocer",
"considera",
"consideró",
"contra",
"cosas",
"creo",
"cual",
"cuales",
"cualquier",
"cuando",
"cuanto",
"cuatro",
"cuenta",
"cómo",
"da",
"dado",
"dan",
"dar",
"de",
"debe",
"deben",
"debido",
"decir",
"dejó",
"del",
"demás",
"dentro",
"desde",
"después",
"dice",
"dicen",
"dicho",
"dieron",
"diferente",
"diferentes",
"dijeron",
"dijo",
"dio",
"donde",
"dos",
"durante",
"e",
"ejemplo",
"el",
"ella",
"ellas",
"ello",
"ellos",
"embargo",
"en",
"encuentra",
"entonces",
"entre",
"era",
"eran",
"es",
"esa",
"esas",
"ese",
"eso",
"esos",
"esta",
"estaba",
"estaban",
"estamos",
"estar",
"estará",
"estas",
"este",
"esto",
"estos",
"estoy",
"estuvo",
"está",
"están",
"ex",
"existe",
"existen",
"explicó",
"expresó",
"fin",
"fue",
"fuera",
"fueron",
"gran",
"grandes",
"ha",
"haber",
"habrá",
"había",
"habían",
"hace",
"hacen",
"hacer",
"hacerlo",
"hacia",
"haciendo",
"han",
"hasta",
"hay",
"haya",
"he",
"hecho",
"hemos",
"hicieron",
"hizo",
"hoy",
"hubo",
"igual",
"incluso",
"indicó",
"informó",
"junto",
"la",
"lado",
"las",
"le",
"les",
"llegó",
"lleva",
"llevar",
"lo",
"los",
"luego",
"lugar",
"manera",
"manifestó",
"mayor",
"me",
"mediante",
"mejor",
"mencionó",
"menos",
"mi",
"mientras",
"misma",
"mismas",
"mismo",
"mismos",
"momento",
"mucha",
"muchas",
"mucho",
"muchos",
"muy",
"más",
"nada",
"nadie",
"ni",
"ninguna",
"ningunas",
"ninguno",
"ningunos",
"ningún",
"no",
"nos",
"nosotras",
"nosotros",
"nuestra",
"nuestras",
"nuestro",
"nuestros",
"nueva",
"nuevas",
"nuevo",
"nuevos",
"nunca",
"o",
"ocho",
"otra",
"otras",
"otro",
"otros",
"para",
"parece",
"parte",
"partir",
"pasada",
"pasado",
"pero",
"pesar",
"poca",
"pocas",
"poco",
"pocos",
"podemos",
"podrá",
"podrán",
"podría",
"podrían",
"poner",
"por",
"porque",
"posible",
"primer",
"primera",
"primero",
"primeros",
"principalmente",
"propia",
"propias",
"propio",
"propios",
"próximo",
"próximos",
"pudo",
"pueda",
"puede",
"pueden",
"pues",
"que",
"quedó",
"queremos",
"quien",
"quienes",
"quiere",
"quién",
"qué",
"realizado",
"realizar",
"realizó",
"respecto",
"se",
"sea",
"sean",
"segunda",
"segundo",
"según",
"seis",
"ser",
"será",
"serán",
"sería",
"señaló",
"si",
"sido",
"siempre",
"siendo",
"siete",
"sigue",
"siguiente",
"sin",
"sino",
"sobre",
"sola",
"solamente",
"solas",
"solo",
"solos",
"son",
"su",
"sus",
"sí",
"sólo",
"tal",
"también",
"tampoco",
"tan",
"tanto",
"tendrá",
"tendrán",
"tenemos",
"tener",
"tenga",
"tengo",
"tenido",
"tenía",
"tercera",
"tiene",
"tienen",
"toda",
"todas",
"todavía",
"todo",
"todos",
"total",
"tras",
"trata",
"través",
"tres",
"tuvo",
"un",
"una",
"unas",
"uno",
"unos",
"usted",
"va",
"vamos",
"van",
"varias",
"varios",
"veces",
"ver",
"vez",
"y",
"ya",
"yo",
"él",
"ésta",
"éstas",
"éste",
"éstos",
"última",
"últimas",
"último",
"últimos",
};


char *stoplist_it [] = {
"a",
"abbastanza",
"accidenti",
"ad",
"adesso",
"affinche",
"agli",
"ahime",
"ahimÃ¨",
"ai",
"al",
"alcuna",
"alcuni",
"alcuno",
"all",
"alla",
"alle",
"allo",
"altri",
"altrimenti",
"altro",
"altrui",
"anche",
"ancora",
"anni",
"anno",
"ansa",
"assai",
"attesa",
"avanti",
"avendo",
"avente",
"aver",
"avere",
"avete",
"aveva",
"avuta",
"avute",
"avuti",
"avuto",
"basta",
"bene",
"benissimo",
"berlusconi",
"brava",
"bravo",
"c",
"casa",
"caso",
"cento",
"certa",
"certe",
"certi",
"certo",
"che",
"chi",
"chicchessia",
"chiunque",
"ci",
"ciascuna",
"ciascuno",
"cima",
"cio",
"cioe",
"cioÃ¨",
"circa",
"citta",
"cittÃ ",
"ciÃ²",
"codesta",
"codesti",
"codesto",
"cogli",
"coi",
"col",
"colei",
"coll",
"coloro",
"colui",
"come",
"con",
"concernente",
"consiglio",
"contro",
"cortesia",
"cos",
"cosa",
"cosi",
"cosÃ¬",
"cui",
"d",
"da",
"dagli",
"dai",
"dal",
"dall",
"dalla",
"dalle",
"dallo",
"davanti",
"degli",
"dei",
"del",
"dell",
"della",
"delle",
"dello",
"dentro",
"detto",
"deve",
"di",
"dice",
"dietro",
"dire",
"dirimpetto",
"dopo",
"dove",
"dovra",
"dovrÃ ",
"due",
"dunque",
"durante",
"e",
"ecco",
"ed",
"egli",
"ella",
"eppure",
"era",
"erano",
"esse",
"essendo",
"esser",
"essere",
"essi",
"ex",
"fa",
"fare",
"fatto",
"favore",
"fin",
"finalmente",
"finche",
"fine",
"fino",
"forse",
"fra",
"fuori",
"gia",
"giacche",
"giorni",
"giorno",
"giÃ ",
"gli",
"gliela",
"gliele",
"glieli",
"glielo",
"gliene",
"governo",
"grande",
"grazie",
"gruppo",
"ha",
"hai",
"hanno",
"ho",
"i",
"ieri",
"il",
"improvviso",
"in",
"infatti",
"insieme",
"intanto",
"intorno",
"invece",
"io",
"l",
"la",
"lavoro",
"le",
"lei",
"li",
"lo",
"lontano",
"loro",
"lui",
"lungo",
"lÃ ",
"ma",
"macche",
"magari",
"mai",
"male",
"malgrado",
"malissimo",
"me",
"medesimo",
"mediante",
"meglio",
"meno",
"mentre",
"mesi",
"mezzo",
"mi",
"mia",
"mie",
"miei",
"mila",
"miliardi",
"milioni",
"ministro",
"mio",
"moltissimo",
"molto",
"mondo",
"nazionale",
"ne",
"negli",
"nei",
"nel",
"nell",
"nella",
"nelle",
"nello",
"nemmeno",
"neppure",
"nessuna",
"nessuno",
"niente",
"no",
"noi",
"non",
"nondimeno",
"nostra",
"nostre",
"nostri",
"nostro",
"nulla",
"nuovo",
"o",
"od",
"oggi",
"ogni",
"ognuna",
"ognuno",
"oltre",
"oppure",
"ora",
"ore",
"osi",
"ossia",
"paese",
"parecchi",
"parecchie",
"parecchio",
"parte",
"partendo",
"peccato",
"peggio",
"per",
"perche",
"perchÃ¨",
"percio",
"perciÃ²",
"perfino",
"pero",
"persone",
"perÃ²",
"piedi",
"pieno",
"piglia",
"piu",
"piÃ¹",
"po",
"pochissimo",
"poco",
"poi",
"poiche",
"press",
"prima",
"primo",
"proprio",
"puo",
"pure",
"purtroppo",
"puÃ²",
"qualche",
"qualcuna",
"qualcuno",
"quale",
"quali",
"qualunque",
"quando",
"quanta",
"quante",
"quanti",
"quanto",
"quantunque",
"quasi",
"quattro",
"quel",
"quella",
"quelli",
"quello",
"quest",
"questa",
"queste",
"questi",
"questo",
"qui",
"quindi",
"riecco",
"salvo",
"sara",
"sarebbe",
"sarÃ ",
"scopo",
"scorso",
"se",
"secondo",
"seguente",
"sei",
"sempre",
"senza",
"si",
"sia",
"siamo",
"siete",
"solito",
"solo",
"sono",
"sopra",
"sotto",
"sta",
"staranno",
"stata",
"state",
"stati",
"stato",
"stesso",
"su",
"sua",
"successivo",
"sue",
"sugli",
"sui",
"sul",
"sull",
"sulla",
"sulle",
"sullo",
"suo",
"suoi",
"tale",
"talvolta",
"tanto",
"te",
"tempo",
"ti",
"torino",
"tra",
"tranne",
"tre",
"troppo",
"tu",
"tua",
"tue",
"tuo",
"tuoi",
"tutta",
"tuttavia",
"tutte",
"tutti",
"tutto",
"uguali",
"un",
"una",
"uno",
"uomo",
"va",
"vale",
"varia",
"varie",
"vario",
"verso",
"vi",
"via",
"vicino",
"visto",
"vita",
"voi",
"volta",
"vostra",
"vostre",
"vostri",
"vostro",
"Ã¨",
};


char *stoplist_fr [] = {
"a",
"abord",
"afin",
"ah",
"ai",
"aie",
"ainsi",
"allaient",
"allo",
"allons",
"allô",
"après",
"assez",
"attendu",
"au",
"aucun",
"aucune",
"aujourd",
"aujourd'hui",
"auquel",
"aura",
"auront",
"aussi",
"autre",
"autres",
"aux",
"auxquelles",
"auxquels",
"avaient",
"avais",
"avait",
"avant",
"avec",
"avoir",
"ayant",
"b",
"bah",
"beaucoup",
"bien",
"bigre",
"boum",
"bravo",
"brrr",
"c",
"car",
"ce",
"ceci",
"cela",
"celle",
"celle-ci",
"celle-là",
"celles",
"celles-ci",
"celles-là",
"celui",
"celui-ci",
"celui-là",
"cent",
"cependant",
"certain",
"certaine",
"certaines",
"certains",
"certes",
"ces",
"cet",
"cette",
"ceux",
"ceux-ci",
"ceux-là",
"chacun",
"chaque",
"cher",
"chers",
"chez",
"chiche",
"chut",
"chère",
"chères",
"ci",
"cinq",
"cinquantaine",
"cinquante",
"cinquantième",
"cinquième",
"clac",
"clic",
"combien",
"comme",
"comment",
"compris",
"concernant",
"contre",
"couic",
"crac",
"d",
"da",
"dans",
"de",
"debout",
"dedans",
"dehors",
"delà",
"depuis",
"derrière",
"des",
"desquelles",
"desquels",
"dessous",
"dessus",
"deux",
"deuxième",
"deuxièmement",
"devant",
"devers",
"devra",
"différent",
"différente",
"différentes",
"différents",
"dire",
"divers",
"diverse",
"diverses",
"dix",
"dix-huit",
"dix-neuf",
"dix-sept",
"dixième",
"doit",
"doivent",
"donc",
"dont",
"douze",
"douzième",
"dring",
"du",
"duquel",
"durant",
"dès",
"désormais",
"e",
"effet",
"eh",
"elle",
"elle-même",
"elles",
"elles-mêmes",
"en",
"encore",
"entre",
"envers",
"environ",
"es",
"est",
"et",
"etant",
"etc",
"etre",
"eu",
"euh",
"eux",
"eux-mêmes",
"excepté",
"f",
"fais",
"faisaient",
"faisant",
"fait",
"façon",
"feront",
"fi",
"flac",
"floc",
"font",
"g",
"gens",
"h",
"ha",
"hein",
"hem",
"hep",
"hi",
"ho",
"holà",
"hop",
"hormis",
"hors",
"hou",
"houp",
"hue",
"hui",
"huit",
"huitième",
"hum",
"hurrah",
"hé",
"hélas",
"i",
"il",
"ils",
"importe",
"j",
"je",
"jusqu",
"jusque",
"k",
"l",
"la",
"laquelle",
"las",
"le",
"lequel",
"les",
"lesquelles",
"lesquels",
"leur",
"leurs",
"longtemps",
"lorsque",
"lui",
"lui-même",
"là",
"lès",
"m",
"ma",
"maint",
"mais",
"malgré",
"me",
"merci",
"mes",
"mien",
"mienne",
"miennes",
"miens",
"mille",
"mince",
"moi",
"moi-même",
"moins",
"mon",
"moyennant",
"même",
"mêmes",
"n",
"na",
"ne",
"neuf",
"neuvième",
"ni",
"nombreuses",
"nombreux",
"non",
"nos",
"notre",
"nous",
"nous-mêmes",
"nul",
"néanmoins",
"nôtre",
"nôtres",
"o",
"oh",
"ohé",
"ollé",
"olé",
"on",
"ont",
"onze",
"onzième",
"ore",
"ou",
"ouf",
"ouias",
"oust",
"ouste",
"outre",
"o|",
"où",
"p",
"paf",
"pan",
"par",
"parmi",
"partant",
"particulier",
"particulière",
"particulièrement",
"pas",
"passé",
"pendant",
"personne",
"peu",
"peut",
"peuvent",
"peux",
"pff",
"pfft",
"pfut",
"pif",
"plein",
"plouf",
"plus",
"plusieurs",
"plutôt",
"pouah",
"pour",
"pourquoi",
"premier",
"première",
"premièrement",
"proche",
"près",
"psitt",
"puisque",
"q",
"qu",
"quand",
"quant",
"quant-à-soi",
"quanta",
"quarante",
"quatorze",
"quatre",
"quatre-vingt",
"quatrième",
"quatrièmement",
"que",
"quel",
"quelconque",
"quelle",
"quelles",
"quelqu'un",
"quelque",
"quelques",
"quels",
"qui",
"quiconque",
"quinze",
"quoi",
"quoique",
"r",
"revoici",
"revoilà",
"rien",
"s",
"sa",
"sacrebleu",
"sans",
"sapristi",
"sauf",
"se",
"seize",
"selon",
"sept",
"septième",
"sera",
"seront",
"ses",
"si",
"sien",
"sienne",
"siennes",
"siens",
"sinon",
"six",
"sixième",
"soi",
"soi-même",
"soit",
"soixante",
"son",
"sont",
"sous",
"stop",
"suis",
"suivant",
"sur",
"surtout",
"t",
"ta",
"tac",
"tant",
"te",
"tel",
"telle",
"tellement",
"telles",
"tels",
"tenant",
"tes",
"tic",
"tien",
"tienne",
"tiennes",
"tiens",
"toc",
"toi",
"toi-même",
"ton",
"touchant",
"toujours",
"tous",
"tout",
"toute",
"toutes",
"treize",
"trente",
"trois",
"troisième",
"troisièmement",
"trop",
"très",
"tsoin",
"tsouin",
"tu",
"té",
"u",
"un",
"une",
"unes",
"uns",
"v",
"va",
"vais",
"vas",
"vers",
"via",
"vif",
"vifs",
"vingt",
"vivat",
"vive",
"vives",
"vlan",
"voici",
"voilà",
"vont",
"vos",
"votre",
"vous",
"vous-mêmes",
"vu",
"vé",
"vôtre",
"vôtres",
"w",
"x",
"y",
"z",
"zut",
"à",
"â",
"ça",
"ès",
"étaient",
"étais",
"était",
"étant",
"été",
"être",
"ô",
};

char *stoplist_de [] = {
"Ernst",
"Ordnung",
"Schluss",
"a",
"ab",
"aber",
"aber",
"ach",
"acht",
"achte",
"achten",
"achter",
"achtes",
"ag",
"alle",
"allein",
"allem",
"allen",
"aller",
"allerdings",
"alles",
"allgemeinen",
"als",
"als",
"also",
"am",
"an",
"andere",
"anderen",
"andern",
"anders",
"au",
"auch",
"auch",
"auf",
"aus",
"ausser",
"ausserdem",
"außer",
"außerdem",
"b",
"bald",
"bei",
"beide",
"beiden",
"beim",
"beispiel",
"bekannt",
"bereits",
"besonders",
"besser",
"besten",
"bin",
"bis",
"bisher",
"bist",
"c",
"d",
"d.h",
"da",
"dabei",
"dadurch",
"dafür",
"dagegen",
"daher",
"dahin",
"dahinter",
"damals",
"damit",
"danach",
"daneben",
"dank",
"dann",
"daran",
"darauf",
"daraus",
"darf",
"darfst",
"darin",
"darum",
"darunter",
"darüber",
"das",
"das",
"dasein",
"daselbst",
"dass",
"dasselbe",
"davon",
"davor",
"dazu",
"dazwischen",
"daß",
"dein",
"deine",
"deinem",
"deiner",
"dem",
"dementsprechend",
"demgegenüber",
"demgemäss",
"demgemäß",
"demselben",
"demzufolge",
"den",
"denen",
"denn",
"denn",
"denselben",
"der",
"deren",
"derjenige",
"derjenigen",
"dermassen",
"dermaßen",
"derselbe",
"derselben",
"des",
"deshalb",
"desselben",
"dessen",
"deswegen",
"dich",
"die",
"diejenige",
"diejenigen",
"dies",
"diese",
"dieselbe",
"dieselben",
"diesem",
"diesen",
"dieser",
"dieses",
"dir",
"doch",
"dort",
"drei",
"drin",
"dritte",
"dritten",
"dritter",
"drittes",
"du",
"durch",
"durchaus",
"durfte",
"durften",
"dürfen",
"dürft",
"e",
"eben",
"ebenso",
"ehrlich",
"ei",
"ei,",
"ei,",
"eigen",
"eigene",
"eigenen",
"eigener",
"eigenes",
"ein",
"einander",
"eine",
"einem",
"einen",
"einer",
"eines",
"einige",
"einigen",
"einiger",
"einiges",
"einmal",
"einmal",
"eins",
"elf",
"en",
"ende",
"endlich",
"entweder",
"entweder",
"er",
"erst",
"erste",
"ersten",
"erster",
"erstes",
"es",
"etwa",
"etwas",
"euch",
"f",
"früher",
"fünf",
"fünfte",
"fünften",
"fünfter",
"fünftes",
"für",
"g",
"gab",
"ganz",
"ganze",
"ganzen",
"ganzer",
"ganzes",
"gar",
"gedurft",
"gegen",
"gegenüber",
"gehabt",
"gehen",
"geht",
"gekannt",
"gekonnt",
"gemacht",
"gemocht",
"gemusst",
"genug",
"gerade",
"gern",
"gesagt",
"gesagt",
"geschweige",
"gewesen",
"gewollt",
"geworden",
"gibt",
"ging",
"gleich",
"gott",
"gross",
"grosse",
"grossen",
"grosser",
"grosses",
"groß",
"große",
"großen",
"großer",
"großes",
"gut",
"gute",
"guter",
"gutes",
"h",
"habe",
"haben",
"habt",
"hast",
"hat",
"hatte",
"hatten",
"heisst",
"her",
"heute",
"hier",
"hin",
"hinter",
"hoch",
"hätte",
"hätten",
"i",
"ich",
"ihm",
"ihn",
"ihnen",
"ihr",
"ihre",
"ihrem",
"ihren",
"ihrer",
"ihres",
"im",
"im",
"immer",
"in",
"in",
"indem",
"infolgedessen",
"ins",
"irgend",
"ist",
"j",
"ja",
"ja",
"jahr",
"jahre",
"jahren",
"je",
"jede",
"jedem",
"jeden",
"jeder",
"jedermann",
"jedermanns",
"jedoch",
"jemand",
"jemandem",
"jemanden",
"jene",
"jenem",
"jenen",
"jener",
"jenes",
"jetzt",
"k",
"kam",
"kann",
"kannst",
"kaum",
"kein",
"keine",
"keinem",
"keinen",
"keiner",
"kleine",
"kleinen",
"kleiner",
"kleines",
"kommen",
"kommt",
"konnte",
"konnten",
"kurz",
"können",
"könnt",
"könnte",
"l",
"lang",
"lange",
"lange",
"leicht",
"leide",
"lieber",
"los",
"m",
"machen",
"macht",
"machte",
"mag",
"magst",
"mahn",
"man",
"manche",
"manchem",
"manchen",
"mancher",
"manches",
"mann",
"mehr",
"mein",
"meine",
"meinem",
"meinen",
"meiner",
"meines",
"mensch",
"menschen",
"mich",
"mir",
"mit",
"mittel",
"mochte",
"mochten",
"morgen",
"muss",
"musst",
"musste",
"mussten",
"muß",
"möchte",
"mögen",
"möglich",
"mögt",
"müssen",
"müsst",
"n",
"na",
"nach",
"nachdem",
"nahm",
"natürlich",
"neben",
"nein",
"neue",
"neuen",
"neun",
"neunte",
"neunten",
"neunter",
"neuntes",
"nicht",
"nicht",
"nichts",
"nie",
"niemand",
"niemandem",
"niemanden",
"noch",
"nun",
"nun",
"nur",
"o",
"ob",
"ob",
"oben",
"oder",
"oder",
"offen",
"oft",
"oft",
"ohne",
"p",
"q",
"r",
"recht",
"rechte",
"rechten",
"rechter",
"rechtes",
"richtig",
"rund",
"s",
"sa",
"sache",
"sagt",
"sagte",
"sah",
"satt",
"schlecht",
"schon",
"sechs",
"sechste",
"sechsten",
"sechster",
"sechstes",
"sehr",
"sei",
"sei",
"seid",
"seien",
"sein",
"seine",
"seinem",
"seinen",
"seiner",
"seines",
"seit",
"seitdem",
"selbst",
"selbst",
"sich",
"sie",
"sieben",
"siebente",
"siebenten",
"siebenter",
"siebentes",
"sind",
"so",
"solang",
"solche",
"solchem",
"solchen",
"solcher",
"solches",
"soll",
"sollen",
"sollte",
"sollten",
"sondern",
"sonst",
"sowie",
"später",
"statt",
"t",
"tag",
"tage",
"tagen",
"tat",
"teil",
"tel",
"tritt",
"trotzdem",
"tun",
"u",
"uhr",
"um",
"und",
"und?",
"uns",
"unser",
"unsere",
"unserer",
"unter",
"v",
"vergangenen",
"viel",
"viele",
"vielem",
"vielen",
"vielleicht",
"vier",
"vierte",
"vierten",
"vierter",
"viertes",
"vom",
"von",
"vor",
"w",
"wahr?",
"wann",
"war",
"waren",
"wart",
"warum",
"was",
"wegen",
"weil",
"weit",
"weiter",
"weitere",
"weiteren",
"weiteres",
"welche",
"welchem",
"welchen",
"welcher",
"welches",
"wem",
"wen",
"wenig",
"wenig",
"wenige",
"weniger",
"weniges",
"wenigstens",
"wenn",
"wenn",
"wer",
"werde",
"werden",
"werdet",
"wessen",
"wie",
"wie",
"wieder",
"will",
"willst",
"wir",
"wird",
"wirklich",
"wirst",
"wo",
"wohl",
"wollen",
"wollt",
"wollte",
"wollten",
"worden",
"wurde",
"wurden",
"während",
"währenddem",
"währenddessen",
"wäre",
"würde",
"würden",
"x",
"y",
"z",
"z.b",
"zehn",
"zehnte",
"zehnten",
"zehnter",
"zehntes",
"zeit",
"zu",
"zuerst",
"zugleich",
"zum",
"zum",
"zunächst",
"zur",
"zurück",
"zusammen",
"zwanzig",
"zwar",
"zwar",
"zwei",
"zweite",
"zweiten",
"zweiter",
"zweites",
"zwischen",
"zwölf",
"über",
"überhaupt",
"übrigens",
};

#endif
